#
# spec file for package libayatana-indicator
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor gtk2%{nil}
%if "%{flavor}" == "gtk2"
%global gtkver 2
%endif
%if "%{flavor}" == "gtk3"
%global psuffix 3
%global gtkver 3
%endif
%define sover   7

%define common_name ayatana-indicator%{?psuffix:%{psuffix}-}%{?sover}-common

Name:           libayatana-indicator
Version:        0.9.4
Release:        1.1
Summary:        Ayatana panel indicator applet libraries
License:        GPL-3.0-only
Group:          System/GUI/Other
URL:            https://github.com/AyatanaIndicators/libayatana-indicator
Source0:        https://github.com/AyatanaIndicators/libayatana-indicator/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
%if "%{flavor}" == ""
ExclusiveArch:  do-not-build
%endif
%if "%{flavor}" == "gtk2"
BuildRequires:  pkgconfig(gtk+-2.0)
%else
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libayatana-ido3-0.4) >= 0.8.2
%endif

%description
This library contains information to build indicators to go into
the indicator applet.

%package -n %{common_name}
Summary:        Common files used by libayatana-indicator
BuildArch:      noarch
# No translations provided currently.
#Recommends:    %%{common_name}-lang

%description -n %{common_name}
This library contains information to build indicators to go into
the indicator applet.

This package contains common files.



#%%lang_package -n %%{common_name}
%package -n libayatana-indicator%{?psuffix:%{psuffix}-}%{sover}
Summary:        Ayatana panel indicator applet library
Group:          System/Libraries
Requires:       %{common_name} = %{version}

%description -n libayatana-indicator%{?psuffix:%{psuffix}-}%{sover}
This package provides the libraries required to build indicators
and to go into the indicator applet.

%package -n libayatana-indicator%{?psuffix}-devel
Summary:        Development files for the Ayatana panel indicator applet library
Group:          Development/Libraries/Other
Requires:       libayatana-indicator%{?psuffix:%{psuffix}-}%{sover} = %{version}

%description -n libayatana-indicator%{?psuffix}-devel
This package provides the development files required to build
indicators and to go into the indicator applet.

%prep
%setup -q

%build
%cmake \
%if "%{flavor}" == "gtk2"
  -DFLAVOUR_GTK2=ON
%else
%if 0%{?sle_version} <= 150200
  -DCMAKE_INSTALL_LIBEXECDIR=%{_libexecdir} \
%endif
  -DFLAVOUR_GTK3=ON
%endif
%cmake_build

%install
%cmake_install

#%%find_lang %%{name}

# The library is not created with the proper executable permissions for some
# reason, which creates quite a few problems, so fix that up manually.
chmod +x %{buildroot}%{_libdir}/libayatana-indicator%{?psuffix}.so.%{sover}*
%if "%{flavor}" != "gtk2"
chmod +x %{buildroot}%{_libexecdir}/libayatana-indicator/*
%endif

# Create empty directory for owning within this package.
install -d -m 755 %{buildroot}%{_libdir}/ayatana-indicators%{?psuffix}/%{sover}

%post -n libayatana-indicator%{?psuffix:%{psuffix}-}%{sover} -p /sbin/ldconfig

%postun -n libayatana-indicator%{?psuffix:%{psuffix}-}%{sover} -p /sbin/ldconfig

%files -n %{common_name}
%license COPYING
%doc AUTHORS INSTALL.md NEWS NEWS.Canonical
%if "%{flavor}" != "gtk2"
%{_datadir}/libayatana-indicator/
%endif

%files -n libayatana-indicator%{?psuffix:%{psuffix}-}%{sover}
%license COPYING
%dir %{_libdir}/ayatana-indicators%{?psuffix}/
%dir %{_libdir}/ayatana-indicators%{?psuffix}/%{sover}/
%{_libdir}/libayatana-indicator%{?psuffix}.so.%{sover}*
%if "%{flavor}" != "gtk2"
%{_libexecdir}/libayatana-indicator/
%endif

%files -n libayatana-indicator%{?psuffix}-devel
%{_includedir}/libayatana-indicator%{?psuffix}-0.4/
%{_libdir}/libayatana-indicator%{?psuffix}.so
%{_libdir}/pkgconfig/ayatana-indicator%{?psuffix}-0.4.pc

#%%files -n %%{common_name}-lang -f %%{name}.lang

%changelog
* Fri Oct 13 2023 Mihai Moldovan <ionic@ionic.de>
- Update to new upstream version 0.9.4:
  * cmake: Install library as library.
* Thu Oct 27 2022 Mihai Moldovan <ionic@ionic.de>
- Update to version 0.9.3:
  * Add tooltip support.
  * src/indicator-service.c: Make failure to connect to the
    session DBus fatal.
  * src/indicator-ng.c: Do not show tooltip on labels while the
    menu is open.
- Add rpmlint override file to sources list.
* Fri Jun  3 2022 Mihai Moldovan <ionic@ionic.de>
- Update to version 0.9.1:
  * src/{CMakeLists.txt,indicator.symbols}: Don't export private
    symbols. Immitate symbol exports as previously done with
    libtool.
- Provide an empty, but owned directory within %%{_libdir} for
  actual indicator "plugins".
- Switch to packaging NEWS instead of ChangeLog (much smaller),
  package INSTALL.md and NEWS.Canonical as documentation files.
- Fix library without executable permission.
- Split package up into lib packages and a -common package.
- Add language support, but comment out for now, since upstream
  does not provide translations yet.
- Move datadir files into common package.
- Add *SuSE 15.2 support, need to define CMAKE_INSTALL_LIBEXECDIR,
  since the default does not fit and the cmake package doesn't
  provide the argument by default on older systems.
- Add rpmlint filters for warnings and errors that do not really
  concern us.
* Sat Nov 20 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.9.0 (changes since 0.6.2):
  * Break compatibility with all system indicators before 0.8.0.
  * Switch from autotools to CMake.
  * GObject private API/ABI: Get rid of g_type_class_add_private()
    and use DEFINE_TYPE_WITH_PRIVATE().
  * Display IDO widgets/Use own action muxer/Allow IDO CSS styling.
  * Make building of ayatana-indicator-loader3 optional.
  * Display and connect the Indicator Messages widgets.
  * Fix width of menu panes.
  * Use ayatanamenuitemfactory.(c|h) from ayatana-ido.
    Reduce code duplications. This also freeze renderer freezes on
    some systems.
  * libayatana-indicator/indicator-ng.c: Try to prevent cascading
    failure if IDO creation fails.
  * Rename Ayatana Indicators specific x-canonical-* attributes to
    x-ayatana-* (esp. x-ayatana-type).
    This makes Ayatana Indicators work on Ubuntu.
  * Use ayatana-indicators.target (from libayatana-common) as the
    systemd lifecycle unit, not ayatana-indicators-pre.target.
  * Fix tests and deprecations.
  * libayatana-indicator/indicator-ng.c: Resize open menus as items
    change.
  * Enable menu scrolling + reset offset on popup. Resolves display
    problems with Indicator Messges consumers that provide too-long
    of a list of unread messages (so that the scrolling kicks in in
    the indicator's menu).
  * Fix IDO insertion index in Indicator Messages with multiple
    clients.
  * Workaround for themes with scrolling arrows on the menu
    borders: disable menu arrows.
  * indicator-ng.c: Fix padding and spacing for hidden indicator
    item labels.
  * Fix duplicate location in the datetime indicator (and
    potentially other duplicated menu item flaws).
  * indicator-ng: Fix menu resizing for all themes.
  * libayatana-indicator/indicator-ng.c: Only run
    gtk_box_set_spacing() if object to operate on is a GTK_BOX.
  * Fix unit tests during package build (properly wrap around Xvfb
    and dbus-wrapper).
  * src/indicator-ng.c: Make sure old menu item name is not NULL
    before comparison.
  * Scale icons when loading from filename.
  * Update/add documentation.
  * Rename library source folder to src/.
  * tools/indicator-loader.c: Silence unused parameter
    warnings/errors for various functions.
  * Fix compiler warnings.
- Drop libayatana-indicator-glib-2.58.patch: fixed upstream.
- Drop libayatana-indicator-Wno-error-deprecated-declarations.patch:
  no longer needed.
- Drop libayatana-indicator-Wno-error-deprecated-declarations-for-tests.patch:
  no longer needed.
- Split gtk2 and gtk3 builds using _multibuild.
* Mon Mar 16 2020 Marguerite Su <i@marguerite.su>
- add libayatana-indicator-Wno-error-deprecated-declarations.patch
  * add Wno-error=deprecated-declarations option to tools
- add libayatana-indicator-glib-2.58.patch
  * g_type_class_add_private was deprecated since glib 2.58
    get rid of it and self-defined *_GET_PRIVATE() functions,
    use G_DEFINE_TYPE_* and auto-generated *_get_instance_private()
    instead.
- drop libayatana-indicator-disable-werror.patch
* Wed Nov  6 2019 Marguerite Su <i@marguerite.su>
- add libayatana-indicator-Wno-error-deprecated-declarations-for-tests.patch
  * the library is built with "Wno-error=deprecated-declarations",
    but tests is built without such option
* Tue Jun 11 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Avoid mate-common for some openSUSE-specific reasons.
* Wed Mar 21 2018 sor.alexei@meowr.ru
- Update to version 0.6.2:
  * Makefile.am: Drop distcheck features.
  * libayatana-indicator/indicator-ng.c: Type cast assignments from
    g_object_ref_sink().
* Mon Mar 19 2018 jengelh@inai.de
- Update summaries.
* Mon Mar 12 2018 sor.alexei@meowr.ru
- Initial package.
